Module eval

Module eval 

Structs

EvalOutput
The resulting output of a call to the SkySpark eval API.

Enums

EvalError
Errors that can occur when executing an eval API call on a SkySpark server.

Functions

eval
A standalone function to call the eval API on a SkySpark server, without creating a SkySparkClient.